@@ -13,6 +13,7 @@ mod build_system;
 mod dependency_groups;
 mod project;
 
+mod coverage;
 mod global;
 mod ruff;
 #[cfg(test)]
@@ -147,6 +148,7 @@ pub fn format_toml(content: &str, opt: &Settings) -> String {
     dependency_groups::fix(&mut tables, opt.keep_full_version);
     ruff::fix(&mut tables);
     uv::fix(&mut tables);
+    coverage::fix(&mut tables);
     reorder_tables(&root_ast, &tables);
     ensure_all_arrays_multiline(&root_ast, opt.column_width);
     common::string::wrap_all_long_strings(&root_ast, opt.column_width, &indent_string);
@@ -176,14 +178,8 @@ pub fn format_toml(content: &str, opt: &Settings) -> String {
 fn remove_blank_lines_between_same_group_tables(content: &str, multi_level_prefixes: &[&str]) -> String {
     let lines: Vec<&str> = content.lines().collect();
     let mut result = Vec::new();
-    let mut skip_next = false;
 
     for i in 0..lines.len() {
-        if skip_next {
-            skip_next = false;
-            continue;
-        }
-
         // Check if this is a blank line between two table headers in the same group
         if lines[i].is_empty() && i > 0 && i + 1 < lines.len() {
             let trimmed_next = lines[i + 1].trim();
@@ -207,7 +203,6 @@ fn remove_blank_lines_between_same_group_tables(content: &str, multi_level_prefi
 
                     if prev_key == next_key {
                         // Same group - skip this blank line
-                        skip_next = false;
                         continue;
                     }
                 }
